pydrad
===========

The :obj:`pydrad` library is a Python 3 package that contains helper functions for specific plots.

License
=======

See `LICENSE` at () for the full text of the license.

As specified in `LICENSE`,

the subpackage, fully enclosed under the directory src/pydrad/models/did,
contains an original adaptation of the GPL-licensed R libraries: r-DRDID & r-did.
The subpackage pydrad.models.did is distributed under GPL.
Please refer to src/pydrad/models/did/LICENSE for the full text of the license.

The rest of the package is distributed under Apache License, Version 2.0


.. toctree::
   :caption: Getting Started
   :hidden:

   getting-started.rst


.. toctree::
   :caption: Basic Usage
   :hidden:

   basic-usage/basic-usage.rst


.. toctree::
   :caption: Development
   :hidden:

   development/installation.rst
   development/unit-tests.rst
   development/formatting.rst
   development/documentation.rst

.. toctree::
   :caption: API
   :hidden:
   :maxdepth: 2

   api.rst


.. toctree::
   :caption: Release Notes
   :hidden:

   release-notes/versioning.rst
   release-notes/v0.0.md
